# Makefile for TabBookTest if your Imake does not work
# Requires GNU gmake: run as follows from the source dir:
# 	gmake -f TabBookTest.make [DEBUG=y] {STATIC=y] 
#
# The symbols OS_NAME  governs the make:
# 	UNIX_SV - Intel Unix/ Novell Unixware 
# 	OSF	- DEC Alpha OSF compliler/linker 
#	LINUX	- LINUX (requires Motif library libXm
#	SunOS	- SUN Solaris (or SUNOS)
#	HP-UX	- HP 10.20
# Options:
#	STATIC - build with static Motif lib (On Linux only)
#	DEBUG - build with debug 
#
# The project base directory (typically TabBook) must have the following
#  subdirectories:
#	.../TabBook/
#	    |__	src - source *.c files & *.h files
#	    |__	obj - Object files will be placed here
#	    |__	bin - executable will be placed here
#
# cd to src then issue the gmake command above
#
# Make sure your PWD is exported - it should be TabBook/src
# For sun, set:
#   LD_LIBRARY_PATH=/usr/dt/lib:/usr/openwin/lib/libp:/usr/lib ; 
#		export LD_LIBRARY_PATH

.SUFFIX: .c .o .h 
ifndef CC
CC=cc
endif

LD=$(CC)

.PHONY : allways

ifndef PWD
allways : 
	@echo "Can not determine PWD, export  PWD from your shell "
	@echo "Or rerun: gmake -f TabBookTest.make  PWD=<current directory>"
	exit 1
endif

ifndef ROOT
ROOT := $(PWD)
ROOT := $(dir $(ROOT))
endif


ifndef OS_NAME
OS_NAME:= $(shell uname -s)
endif

# Where binary is placed
BINDIR := $(ROOT)/bin
# Where Objects are  placed
OBJDIR := $(ROOT)/obj
# Where some h files may be located 
HDRDIR := $(ROOT)/hdr

# default X includes 
X_INCLUDE_DIRS := -I/usr/X/include  


ifdef WALL
CCFLAGS := $(CCFLAGS) -Wall
endif

# Conditional setting of the compiler and linker flags depending on the
# operating system

# Set the test var, if still null at end of this section
# then the OS_NAME var was not matched

OSFOUND=0

##############################################################################
# DEC Alpha OSF compliler/linker requirements:
#
ifeq ($(OS_NAME),OSF1)
OS_NAME := OSF
endif
ifeq ($(OS_NAME),OSF)
#

ifndef DEBUG
DEBUG_FLAGS = -O2 -std1
EXE_LDFLAGS =  -call_shared -O2 
else
DEBUG_FLAGS = -g
EXE_LDFLAGS =  -call_shared 
endif

# Set the X libraries for this machine
XLIBS := -L/usr/lib/X11 -lXm -lX11 -lXaw -lXmu -lXt -lXext
OSFOUND=1
endif

##############################################################################
# IRIX
#
ifeq ($(OS_NAME),IRIX)

ifndef DEBUG
DEBUG_FLAGS =
else
DEBUG_FLAGS = -g
endif

EXE_LDFLAGS =
X_INCLUDE_DIRS := $(X_INCLUDE_DIRS)

# Set the X libraries for this machine
XLIBS := -B static \
-lXm  -lXmu -lXt_s -lX11_s -lXext -lX11_s -lgen

OSFOUND=1
endif

##############################################################################
# Intel Unix/ Novell Unixware requirements:
#
ifeq ($(OS_NAME),UNIX_SV)

ifndef DEBUG
DEBUG_FLAGS = 
else
DEBUG_FLAGS = -g 
endif
CC := gcc
EXE_LDFLAGS = 

# Set the X libraries for this machine, For UNIXWARE, XIM library is needed
ifneq "$(wildcard /usr/X/lib/libXIM.so)" ""
XIM := -lXIM
endif

XLIBS := -lnsl -L/usr/X11/lib -L/usr/X/lib -lXm $(XIM) -lXmu -lXt -lXext -lX11 -lgen

OSFOUND=1
endif

##############################################################################
# Sun Solaris
#
ifeq ($(OS_NAME),SUNOS)
OS_NAME := SunOS
endif
ifeq ($(OS_NAME),SunOS)

ifndef DEBUG
DEBUG_FLAGS = 
else
DEBUG_FLAGS = -g 
endif

EXE_LDFLAGS = 
X_INCLUDE_DIRS := $(X_INCLUDE_DIRS) -I/usr/openwin/share/include -I/usr/dt/include
# Set the X libraries for this machine
XLIBS := -L/usr/dt/lib -L/usr/openwin/lib -L/usr/X11/lib \
-lXm  -lXmu -lXt -lX11 -lXext -lX11 -lgen -lsocket -ldl -lw -lauth -lnsl

OSFOUND=1
endif

##############################################################################
# HP UX
#
ifeq ($(OS_NAME),HP-UX)
OS_NAME := HP_UX
endif

ifeq ($(OS_NAME),HP_UX)
CC=gcc
ifndef DEBUG
DEBUG_FLAGS = 
else
DEBUG_FLAGS = -g 
endif

EXE_LDFLAGS = 
X_INCLUDE_DIRS := $(X_INCLUDE_DIRS) 
# Set the X libraries for this machine
#XLIBS := -L/usr/local/lib/X11R6/lib -lXm  -lXt -lX11 -lXext -lX11 -lXmu 
XLIBS := -L/usr/contrib/X11R6/lib    -lXm  -lXt -lX11 -lXext -lX11 -lXmu 

OSFOUND=1
endif
##########################################################
# Linux - requires Motif
ifeq ($(OS_NAME),Linux)
OS_NAME := LINUX
endif
ifeq ($(OS_NAME),LINUX)

ifndef DEBUG
DEBUG_FLAGS = -O 
else
DEBUG_FLAGS = -g 
endif

ifdef STATIC
MOTIF= /usr/X11/lib/libXm.a
else
MOTIF= -lXm 
endif


EXE_LDFLAGS = 
# Set the X libraries for this machine
XLIBS := -L/usr/X11/lib $(MOTIF) -lXmu -lXpm  -lXt -lXext -lX11
# Set the X includes for this machine
X_INCLUDE_DIRS := -I/usr/X11R6/include  
OSFOUND=1
endif


##############################################################################
# This is the failure condition, or you have forgot to
# add the new operating system uname -s test to this if,else,endif

ifeq ($(OSFOUND),0)

always :
	@-echo "Unsupported OS_NAME environment variable: " $(OS_NAME)
	@-echo  "can not compile"
	exit 1
endif


ifdef XAW
XAW_LIBRARIES := -lXaw -L/usr/ucblib -lucb 
else
CCFLAGS := $(CCFLAGS) -DMOTIF 
endif

# The executable
EXE = $(BINDIR)/TabBookTest

# The objects that make up the executable (Edit)
OBJ 	:= $(OBJDIR)/TabBookTest.o $(OBJDIR)/TabBook.o 

ifeq ($(OS_NAME),HP_UX)
# HP requires this object to be linked in order to be debugged under GDB
# sometimes this file is located in /usr/lib/end.o  
OBJ 	:= $(OBJ) /opt/langtools/lib/end.o
endif

# the main/default  target - build the library from its objects
$(EXE) : $(OBJ)

INCLUDE_DIRS := -I. -I$(HDRDIR) $(X_INCLUDE_DIRS)

# EXE_LIBRARIES, the library modules needed (-L and -l)
EXE_LIBRARIES = $(XLIBS) 
# Widget depends on its private h file 
$(OBJDIR)/TabBook.o : TabBookP.h

.PHONY: clean
clean:
	rm $(OBJ)

# Pattern rules

# Link
$(BINDIR)/% :
	rm -f $(BINDIR)/$(@F)
	$(LD) $(LDFLAGS) $(EXE_LDFLAGS) $^ \
		$(EXE_LIBRARIES) $(XAW_LIBRARIES) -o $(BINDIR)/$(@F)
	chmod a+r $(BINDIR)/$(@F) 

#compile
$(OBJDIR)/%.o : %.c
	$(CC) -o $@ $(CCFLAGS) $(DEBUG_FLAGS) -D$(OS_NAME) $(INCLUDE_DIRS) -c $<
	@-echo _________

